==> cayenne-4.1.1-src.tar.gz: cayenne-4.1.1-src/cayenne-rop-server/src/main/java/org/apache/cayenne/rop/ServerHessianSerializationServiceProvider.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/
package org.apache.cayenne.rop;

import org.apache.cayenne.di.DIRuntimeException;
import org.apache.cayenne.di.Provider;
import org.apache.cayenne.remote.hessian.HessianConfig;
import org.apache.cayenne.remote.hessian.service.ServerSerializerFactory;

public class ServerHessianSerializationServiceProvider implements Provider<ROPSerializationService> {

    public static final String[] SERVER_SERIALIZER_FACTORIES = new String[] {
            ServerSerializerFactory.class.getName()
    };

    @Override
    public ROPSerializationService get() throws DIRuntimeException {
        return new HessianROPSerializationService(
                HessianConfig.createFactory(SERVER_SERIALIZER_FACTORIES, null));
    }
}

==> cayenne-4.2.3-src.tar.gz: cayenne-4.2.3-src/cayenne-rop-server/src/main/java/org/apache/cayenne/rop/ServerHessianSerializationServiceProvider.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/
package org.apache.cayenne.rop;

import java.util.List;

import org.apache.cayenne.DataChannel;
import org.apache.cayenne.di.DIRuntimeException;
import org.apache.cayenne.di.Inject;
import org.apache.cayenne.di.Provider;
import org.apache.cayenne.remote.hessian.HessianConfig;
import org.apache.cayenne.remote.hessian.service.ServerSerializerFactory;

public class ServerHessianSerializationServiceProvider implements Provider<ROPSerializationService> {

    private final Provider<DataChannel> dataChannelProvider;

    private final List<String> serializationWhitelist;

    public static final String[] SERVER_SERIALIZER_FACTORIES = new String[] {
            ServerSerializerFactory.class.getName()
    };

    /**
     * @since 4.2
     */
    public ServerHessianSerializationServiceProvider(@Inject Provider<DataChannel> dataChannelProvider,
                                                     @Inject(ROPConstants.SERIALIZATION_WHITELIST) List<String> serializationWhitelist) {
        this.dataChannelProvider = dataChannelProvider;
        this.serializationWhitelist = serializationWhitelist;
    }

    @Override
    public ROPSerializationService get() throws DIRuntimeException {
        return new HessianROPSerializationService(
                HessianConfig.createFactory(
                        SERVER_SERIALIZER_FACTORIES,
                        dataChannelProvider.get().getEntityResolver(),
                        serializationWhitelist
                )
        );
    }
}
